aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--README2
-rw-r--r--test_qnx/dce_test/dce_test.c2
2 files changed, 2 insertions, 2 deletions
diff --git a/README b/README
index b52b571..515606f 100644
--- a/README
+++ b/README
@@ -493,7 +493,7 @@ If (BUILDOS_LINUX) {
************ Version Info of Headers included in packages folder ***********
Tools:
-XDC version : xdctools_3_25_04_88
+XDC version : xdctools_3_25_05_94
CE version : codec_engine_3_24_00_08
XDAIS version: xdais_7_24_00_04
FC version: framework_components_3_24_02_15
diff --git a/test_qnx/dce_test/dce_test.c b/test_qnx/dce_test/dce_test.c
index a3d8df1..383b4ae 100644
--- a/test_qnx/dce_test/dce_test.c
+++ b/test_qnx/dce_test/dce_test.c
@@ -1404,7 +1404,7 @@ int main(int argc, char * *argv)
buf = (OutputBuffer *)outArgs->outputID[i];
DEBUG("pop: %d (%p)", out_cnt, buf);
- if( out_cnt < 300 ) { // write first 300 frames to output file
+ if( out_cnt < frames_to_write ) { // write first frames_to_write frames to output file as
write_output(out_pattern, out_cnt++, buf->buf + yoff,
buf->buf + uvoff, padded_width);
} else {